import type { ComponentProps } from '@fluentui/react-components';
import type { ComponentState } from '@fluentui/react-components';
import type { DesignVersion } from '@fluentui-copilot/react-provider';
import type { ForwardRefComponent } from '@fluentui/react-components';
import type { ProgressBar } from '@fluentui/react-components';
import * as React_2 from 'react';
import type { Slot } from '@fluentui/react-components';
import type { SlotClassNames } from '@fluentui/react-components';

export declare const OutputCard: ForwardRefComponent<OutputCardProps>;

export declare const outputCardClassNames: SlotClassNames<OutputCardSlots>;

/**
 * OutputCard Props
 */
export declare type OutputCardProps = ComponentProps<OutputCardSlots> & DesignVersion & {
    /**
     * If the card contents are loading.
     * After switching from true to false, the card flair will animate.
     * @default false
     */
    isLoading?: boolean;
    mode?: 'canvas' | 'sidecar';
};

export declare type OutputCardSlots = {
    root: Slot<'div'>;
    /**
     * Progress bar is currently opt in, but will become opt out in 0.9.0
     */
    progress?: Slot<typeof ProgressBar>;
};

/**
 * State used in rendering OutputCard
 */
export declare type OutputCardState = ComponentState<OutputCardSlots> & Required<Pick<OutputCardProps, 'isLoading' | 'mode' | 'designVersion'>> & {
    flairClassName: string;
};

/**
 * Render the final JSX of OutputCard
 */
export declare const renderOutputCard_unstable: (state: OutputCardState) => JSX.Element;

/**
 * Create the state required to render OutputCard.
 *
 * The returned state can be modified with hooks such as useOutputCardStyles_unstable,
 * before being passed to renderOutputCard_unstable.
 *
 * @param props - props from this instance of OutputCard
 * @param ref - reference to root HTMLElement of OutputCard
 */
export declare const useOutputCard_unstable: (props: OutputCardProps, ref: React_2.Ref<HTMLDivElement>) => OutputCardState;

export declare const useOutputCardStyles_unstable: (state: OutputCardState) => OutputCardState;

export { }
